@@ -177,7 +177,7 @@ def raiseErrorLater(err: Exception):
 
 def warnLater(msg: str, type_=Warning):
   if not usingPostponedErrors:
-    warn(msg, type_)
+    warn(msg, type_, stacklevel=2)
   else:
     QtCore.QTimer.singleShot(0, lambda: warn(msg, type_, stacklevel=2))
 
