@@ -129,6 +129,7 @@ class ParamEditor(QtWidgets.QDockWidget):
     self.watcher = QtCore.QFileSystemWatcher()
     """Responsible for detecting changes in the saved states"""
     if self.saveDir is not None:
+      self.saveDir.mkdir(parents=True, exist_ok=True)
       self.watcher.addPath(str(self.saveDir))
     self.watcher.directoryChanged.connect(lambda: self.updateSavedStates())
 
@@ -180,7 +181,6 @@ class ParamEditor(QtWidgets.QDockWidget):
       paramState = fns.paramValues(self.params, includeDefaults=includeDefaults or allowOverwriteDefault)
     # Remove non-useful values
     if not blockWrite and self.saveDir is not None:
-      self.saveDir.mkdir(parents=True, exist_ok=True)
       fns.saveToFile(paramState, self.formatFileName(saveName),
                  allowOverwriteDefault=allowOverwriteDefault)
     # self.applyChanges()
@@ -544,14 +544,19 @@ class ParamEditor(QtWidgets.QDockWidget):
     self.saveAsBtn = QtWidgets.QPushButton('Save As...')
     self.applyBtn = QtWidgets.QPushButton('Apply')
 
-    self.stateSelector = PopupLineEditor(clearOnComplete=False)
+    self.stateSelector = PopupLineEditor(clearOnComplete=False, parent=self)
     """Shows current state or load a new one"""
+    def onReturn():
+      val = self.stateSelector.text()
+      if val in self.savedStates and val != self.lastAppliedName:
+        self.loadParamValues(val)
+    self.stateSelector.returnPressed.connect(onReturn)
 
     # -----------
     # Widget layout
     # -----------
     children = [
-      [QtWidgets.QLabel('Current state: '), self.stateSelector],
+      [QtWidgets.QLabel('Load state: '), self.stateSelector],
       [self.expandAllBtn, self.collapseAllBtn],
       self.tree,
       [self.saveAsBtn, self.applyBtn]
