@@ -261,9 +261,16 @@ class _DummySignal:
   def connect(self, *args): pass
   def disconnect(self, *args): pass
 
+# WidgetParameterItem is not a QObject, so it can't emit signals. Use a dummy class instead
+class _Emitter(QtCore.QObject):
+  sigChanging = QtCore.Signal(object)
+  sigChanged = QtCore.Signal(object)
+
 class FilePickerParameterItem(parameterTypes.WidgetParameterItem):
   def makeWidget(self):
     param = self.param
+    self._emitter = _Emitter()
+
     if param.opts['value'] is None:
       param.opts['value'] = ''
     fpath = param.opts['value']
@@ -271,7 +278,7 @@ class FilePickerParameterItem(parameterTypes.WidgetParameterItem):
     param.opts.setdefault('existing', True)
     button = QtWidgets.QPushButton()
     button.setValue = button.setText
-    button.sigChanged = _DummySignal()
+    button.sigChanged = self._emitter.sigChanged
     button.value = button.text
     button.setText(fpath)
     button.clicked.connect(self._retrieveFolderName_gui)
@@ -290,15 +297,11 @@ class FilePickerParameterItem(parameterTypes.WidgetParameterItem):
     if fname is None:
       return
     self.param.setValue(fname)
+    self._emitter.sigChanged.emit(fname)
 
 class FilePickerParameter(Parameter):
   itemClass = FilePickerParameterItem
 
-# WidgetParameterItem is not a QObject, so it can't emit signals. Use a dummy class instead
-class _Emitter(QtCore.QObject):
-  sigChanging = QtCore.Signal(object)
-_emitter = _Emitter()
-
 class SliderParameterItem(parameterTypes.WidgetParameterItem):
   slider: QtWidgets.QSlider
   span: np.ndarray
@@ -307,6 +310,9 @@ class SliderParameterItem(parameterTypes.WidgetParameterItem):
   def makeWidget(self):
     param = self.param
     opts = param.opts
+    # Bind to self to avoid garbage collection of signal holder
+    # Bind to self to avoid garbage collection of signal holder
+    _emitter = self._emitter = _Emitter()
 
 
     self.slider = QtWidgets.QSlider()
