@@ -78,7 +78,9 @@ class ProcessIO(dict):
     hyperParamKeys = []
     spec = inspect.signature(func).parameters
     for k, v in spec.items():
-      if k in ignoreKeys: continue
+      if (k in ignoreKeys
+              or v.kind in (v.VAR_POSITIONAL, v.VAR_KEYWORD)):
+        continue
       formattedV = overriddenDefaults.get(k, v.default)
       if formattedV is v.empty:
         formattedV = cls.FROM_PREV_IO
@@ -119,18 +121,22 @@ class ProcessStage(ABC):
   def __str__(self) -> str:
     return repr(self)
 
-  def updateInput(self, prevIo: ProcessIO, **kwargs):
+  def updateInput(self, prevIo: ProcessIO=None, **kwargs):
     """
     Helper function to update current inputs from previous ones while ignoring leading
     underscores.
     """
+    if prevIo is None:
+      prevIo = ProcessIO()
+    useIo = prevIo.copy()
+    useIo.update(kwargs)
     selfFmtToUnfmt = {k.lstrip('_'): k for k in self.input}
     requiredKeyFmt = {k: v for k, v in selfFmtToUnfmt.items() if v in self.input.keysFromPrevIO}
-    prevIoKeyToFmt = {k.lstrip('_'): k for k in {**prevIo, **kwargs}}
+    prevIoKeyToFmt = {k.lstrip('_'): k for k in {**useIo}}
     missingKeys = []
     for fmtK, trueK in selfFmtToUnfmt.items():
       if fmtK in prevIoKeyToFmt:
-        self.input[trueK] = prevIo[prevIoKeyToFmt[fmtK]]
+        self.input[trueK] = useIo[prevIoKeyToFmt[fmtK]]
       elif fmtK in requiredKeyFmt:
         missingKeys.append(fmtK)
     if len(missingKeys) > 0:
