@@ -895,6 +895,7 @@ class PandasTableModel(QtCore.QAbstractTableModel):
 
   def __init__(self, defaultSer: pd.Series, parent=None):
     super().__init__(parent)
+    self.df = pd.DataFrame()
     self.changeDefaultRows(defaultSer)
     self._nextRowId = 0
 
@@ -965,7 +966,7 @@ class PandasTableModel(QtCore.QAbstractTableModel):
 
     # Finally, add new comps
     compsToAdd = rowData.loc[addedIds]
-    self.df = pd.concat((self.compDf, compsToAdd), sort=False)
+    self.df = pd.concat((self.df, compsToAdd), sort=False)
     toEmit['added'] = addedIds
 
     # Retain type information
@@ -973,16 +974,18 @@ class PandasTableModel(QtCore.QAbstractTableModel):
 
     self.layoutChanged.emit()
 
-    self._nextRowId = np.max(self.compDf.index.to_numpy(), initial=-1) + 1
+    self._nextRowId = np.max(self.df.index.to_numpy(), initial=-1) + 1
 
     if emitChange:
-      self.sigCompsChanged.emit(toEmit)
+      self.sigDataChanged.emit(toEmit)
     return toEmit
 
-  def removeDfRows(self, idsToRemove: t.Sequence[int], emitChange=True):
+  def removeDfRows(self, idsToRemove: t.Sequence[int]=None, emitChange=True):
+    if idsToRemove is None:
+      idsToRemove = self.df.index
     toEmit = self.defaultEmitDict.copy()
     # Generate ID list
-    existingCompIds = self.compDf.index
+    existingCompIds = self.df.index
     idsToRemove = np.asarray(idsToRemove)
 
     # Do nothing for IDs not actually in the existing list
@@ -1009,7 +1012,7 @@ class PandasTableModel(QtCore.QAbstractTableModel):
     # Reflect these changes to the component list
     toEmit['deleted'] = idsToRemove
     if emitChange:
-      self.sigCompsChanged.emit(toEmit)
+      self.sigDataChanged.emit(toEmit)
 
   def makeDefaultDfRows(self, numRows=1, initData: pd.DataFrame=None):
     """
